=============
Plot options
=============

This gallery demonstrates the use of several plot options.

functions
=========

.. report:: Trackers.ArrayDataExample
   :render: line-plot
   :width: 200
   :layout: row
   :function: 2,20*math.sin(x)

   A line plot

vline
=====

.. report:: Trackers.ArrayDataExample
   :render: line-plot
   :width: 200
   :layout: row
   :vline: 10,30

   A line plot with vertical lines

